include <../libs/rounded_shapes.scad>

// Dimensions below are for a LM2596HVS device

make_base = false;
make_lid = false;

xv_width = 21.1;
xv_depth = 43;
xv_margin = 0.17;

wall_thickness = 2.0;

depth_margin = 2.1;

box_width = xv_width + wall_thickness*2 + xv_margin;
box_depth = xv_depth + wall_thickness*2 + (2*depth_margin);

base_thickness = 1.6;
lid_thickness = 1.5;

box_height = 15.8 + base_thickness;

vent_radius = xv_depth /32.0;

$fn = 26;
rounding_radius = 2.2;

wire_slot_width = 4;
wire_slot_margin = 0.22;
wire_slot_gap = 3;

adjustment_hole_radius = 4.8 / 2.0;
adjustment_hole_x = 8.5/64.0 * 25.4;
adjustment_hole_y = 63/64.0 * 25.4;
//
lock_height = 7;
lock_thickness = 1.1;

mounting_tab_dim = 9;
mounting_hole_dia = 25.4 * 9/64.0;

mounting_tab_ratio = 3.66;
mounting_tab_thickness = 3.2;

lid_rotate = 0;

vent_qty = (box_depth / (vent_radius + 3.55*vent_radius)) - 1;

if (make_base) {
 
difference(){
    union(){
        rounded_rectangle(box_width, box_depth, box_height, rounding_radius);
        translate([rounding_radius * 1.5, -1 * mounting_tab_dim, 0]){
            difference(){
                rounded_rectangle(box_width/mounting_tab_ratio, box_depth + mounting_tab_dim * 2, mounting_tab_thickness, rounding_radius);
                union(){
                    translate([box_width/mounting_tab_ratio/2,0,-1]){
                        translate([0, mounting_tab_dim/2, 0]){
                            cylinder(r = mounting_hole_dia/2, h = base_thickness*10);
                        }
                        
                        translate([0, (box_depth + mounting_tab_dim *2) - mounting_tab_dim/2, 0]){
                            cylinder(r = mounting_hole_dia/2, h = base_thickness*10);
                        }
                    }
                }
            }
        }
    }
    union(){
        translate([wall_thickness,wall_thickness,base_thickness]){
            cube([xv_width + xv_margin, xv_depth + depth_margin * 2, box_height * 2]);
        }
        
        for(i = [1: 1: 1+vent_qty]){

            translate([xv_width*0.5, wall_thickness * 2 + (vent_radius * 3.55 * i),box_height / 2]){
                rotate([0,90,0]){
                    scale([box_height/ vent_radius/3.33,1,1]){
                        cylinder(r = vent_radius, h = xv_width *2, center = true);
                    }
                }
            }
            
        }
        translate([box_width/2 - wire_slot_width/2,0,base_thickness]){
            cube([wire_slot_width, box_depth, box_height]);
        }
        
    }
}

}

module wire_tab_reinforcement() {
    translate([0,0,box_height - base_thickness -1]){
   rotate([-90,0,90])
linear_extrude(height = wire_slot_width, center = true) {   
   
    polygon(points=[
    [0,0],
    [0, box_height - base_thickness - wire_slot_margin],
    [depth_margin, 0]
    ]);
} 
}
}

if (make_lid) {
rotate([0, lid_rotate, 0]){
// The lid
translate([0,0, box_height * 2.1]){
    union(){
        difference(){
            color("blue") rounded_rectangle(box_width, box_depth, lid_thickness, rounding_radius);
            translate([wall_thickness + xv_margin + adjustment_hole_x, wall_thickness + depth_margin + adjustment_hole_y, -1]){
                cylinder(r = adjustment_hole_radius, h = lid_thickness *10, center = true);
            }
        }                
        
        translate([box_width/2 - wire_slot_width/2,0, -1 * (box_height - wire_slot_gap)]){
            translate([wire_slot_width/2,wall_thickness -wire_slot_margin,1]){
                wire_tab_reinforcement();
            }
            color("red") cube([wire_slot_width, wall_thickness - wire_slot_margin, box_height - wire_slot_gap]);
            
            translate([-1 * lock_thickness, wall_thickness - wire_slot_margin, (box_height - wire_slot_gap) - lock_height + lid_thickness]){
                color("green") cube([wire_slot_width + (2*lock_thickness), lock_thickness, lock_height]);                                
            }
            
            translate([-1 * lock_thickness, box_depth - (wall_thickness - wire_slot_margin) - lock_thickness, (box_height - wire_slot_gap) - lock_height + lid_thickness]){
                color("green") cube([wire_slot_width + (2*lock_thickness), lock_thickness, lock_height]);                                
            }
            
            translate([0,box_depth - wall_thickness + wire_slot_margin,0]){
                
                translate([wire_slot_width/2,0,1]){
                    rotate([0,0,180]){
                        wire_tab_reinforcement();
                    }
                }
                
                color("red") cube([wire_slot_width, wall_thickness - wire_slot_margin, box_height - wire_slot_gap]);
            }
        }
    }
}
}
}
